@@ -293,3 +293,12 @@ function initSubmodule(name) {
         // Running installed, submodule is in $(pkglibdir), nothing to do
     }
 }
+
+function launch(params) {
+    params.flags = params.flags || 0;
+    let app = new Gio.Application({ application_id: params.name,
+                                    flags: (Gio.ApplicationFlags.IS_LAUNCHER |
+                                            params.flags),
+                                  });
+    return app.run(ARGV);
+}
